@@ -179,6 +179,44 @@ dectalk_set_pitch(Speaker *speaker, gdouble new_pitch)
 
 
 
+static gboolean
+dectalk_set_punctuation_mode(Speaker *speaker, gdouble new_punctuation_mode)
+{
+        gchar *command_string;
+        
+        /* Sets the punctuation mode:
+         *
+         *    0: none
+         *    1: some
+         *    2: most
+         *    3: all
+         *
+         * We'll avoid floating point rounding errors by checking for
+         * relative comparisons (e.g., 0 < 0.5, 1 < 1.5, 2 < 2.5, etc.).
+         * In addition, DECtalk only supports none, some, or all, but 
+         * there's seems to be consensus that none, some, most, and all
+         * are punctuation modes that should be supported.  So...we just
+         * equate some and most for DECtalk.
+         */
+        if (new_punctuation_mode < 0.5)
+                command_string = g_strdup_printf ("[:punc none]");
+        else if (new_punctuation_mode < 1.5)
+                command_string = g_strdup_printf ("[:punc some]");
+        else if (new_punctuation_mode < 2.5)
+                command_string = g_strdup_printf ("[:punc some]");
+        else
+                command_string = g_strdup_printf ("[:punc all]");
+
+        /*printf("dectalk_set_punctuation_mode: %s\n", command_string);*/
+
+        dectalk_synthesis_driver_speak_raw (DECTALK_SYNTHESIS_DRIVER(speaker->driver),
+                                      (gchar *) command_string);
+        g_free (command_string);
+        return TRUE;
+}
+
+
+
 DectalkSpeaker *
 dectalk_speaker_new(const GObject *driver,
 		    const GNOME_Speech_VoiceInfo *voice_spec)
@@ -228,10 +266,12 @@ dectalk_speaker_new(const GObject *driver,
 	speaker_add_parameter(s, "rate", 75, 250, 600,
 			      dectalk_set_rate);  
 
-
 	speaker_add_parameter(s, "pitch", 50, voices[voice_num].pitch, 400,
 			      dectalk_set_pitch);  
 
+	speaker_add_parameter(s, "punctuation mode", 0, 0, 3,
+			      dectalk_set_punctuation_mode);  
+
 	return speaker;
 }
 
