@@ -220,7 +220,6 @@ theta__get_synthesizerVersion(PortableServer_Servant servant,
 	return(CORBA_string_dup("2.3"));
 }
 
-
 static GSList *
 get_voice_list(void)
 {
@@ -267,6 +266,49 @@ voice_list_free(GSList *l)
 	g_slist_free(l);
 }
 
+static gboolean
+lang_matches_spec (gchar *lang, gchar *spec)
+{
+	gboolean lang_matches, country_matches = FALSE, encoding_matches = TRUE;
+	if (!strcmp (lang, spec))
+	{
+		return TRUE;
+	}
+	else
+	{
+		gchar *lang_country_cp, *spec_country_cp;
+		gchar *lang_encoding_cp, *spec_encoding_cp;
+		lang_matches = !strncmp (lang, spec, 2);
+		if (lang_matches) 
+		{ 
+			lang_country_cp = strchr (lang, '_');
+			spec_country_cp = strchr (spec, '_');
+			lang_encoding_cp = strchr (lang, '@');
+			spec_encoding_cp = strchr (spec, '@');
+
+			if (!lang_country_cp || !spec_country_cp)
+			{
+				country_matches = TRUE;
+			}
+			else
+			{
+				country_matches = !strncmp (lang_country_cp, spec_country_cp, 3);
+			}
+			if (spec_encoding_cp)
+			{
+				if (lang_encoding_cp)
+				{
+					encoding_matches = !strcmp (spec_encoding_cp, lang_encoding_cp); 
+				}
+				else
+				{
+					encoding_matches = FALSE;
+				}
+			}
+		}
+		return lang_matches && country_matches && encoding_matches;
+	}
+}
 
 static GSList *
 prune_voice_list (GSList *l,
@@ -287,13 +329,14 @@ prune_voice_list (GSList *l,
 				continue;
 			}
 		if (strlen(info->language))
-			if (strcmp (i->language, info->language)) {
+			if (!lang_matches_spec (i->language, info->language)) {
 				CORBA_free (i);
 				l = g_slist_remove_link (l, cur);
 				cur = next;
 				continue;
 			}
-		if (info->gender >= 0 && info->gender != i->gender) {
+		if ((info->gender == GNOME_Speech_gender_male || info->gender == GNOME_Speech_gender_female) && 
+		    (info->gender != i->gender)) {
 			CORBA_free (i);
 			l = g_slist_remove_link (l, cur);
 			cur = next;
