@@ -24,10 +24,10 @@
  */
 
 #include <unistd.h>
+#include <string.h>
 #include <libbonobo.h>
 #include <glib/gmain.h>
 #include <gnome-speech/gnome-speech.h>
-#include <eci.h>
 #include "viavoicesynthesisdriver.h"
 #include "viavoicespeaker.h"
 
@@ -428,29 +428,26 @@ viavoice_speaker_new (GObject *d,
 {
 	ViavoiceSpeaker *speaker;
 	Speaker *s;
-	ECIHand handle;
+	ViavoiceSynthesisDriver *a_driver=(ViavoiceSynthesisDriver*)d;
+	ECIHand handle = a_driver->handle;
 	gint i;
 	gint voice_num = 1;
 	speaker = g_object_new (VIAVOICE_SPEAKER_TYPE, NULL);
 	s = SPEAKER(speaker);
 	enum ECILanguageDialect dialect;
 
-	/* Create a handle and initialize it */
-
-	handle = eciNew ();
-
 	s->driver = g_object_ref (d);
 
         /* Find the specified voice */
 
-	dialect = language_to_dialect(voice_spec->language);
+	dialect = viavoice_synthesis_driver_language_to_dialect(voice_spec->language);
 	eciSetParam(handle, eciLanguageDialect, dialect);
 
 	for (i = 1; i <= ECI_PRESET_VOICES; i++) {
-		char name[30];
+		char name[MAX_VOICE_LENGTH];
 
 		eciGetVoiceName (handle, i, name);
-		if (!g_strcasecmp (voice_spec->name, name))
+		if (0 == g_ascii_strcasecmp (voice_spec->name, name))
 			voice_num = i;
 	}
 
@@ -557,7 +554,6 @@ viavoice_speaker_new (GObject *d,
 				100,
 				viavoice_set_volume);  
 
-	eciDelete (handle);
 	return speaker;
 }
 
