@@ -104,7 +104,7 @@ find_parameter (Speaker *s,
 
 	for (tmp = s->parameters; tmp; tmp = tmp->next) {
 		ParameterPrivate *p = (ParameterPrivate *) tmp->data;
-		if (!g_strcasecmp (name, p->name))
+		if (!g_ascii_strcasecmp (name, p->name))
 			break;
 	}
 	if (tmp)
